
currentFolder = pwd;
foldername= uigetdir(currentFolder,'Select folder that contains simulation data');
s = what(foldername);
datafolder = s.path;

figfoldername= uigetdir(currentFolder,'Select folder to save figures');
s = what(foldername);
f1gdir = s.path;

%f1gdir = 'FigFolder';
scrsz = get(0,'ScreenSize');
set(0,'DefaultAxesFontName', 'Arial')
set(0,'DefaultAxesFontSize', 8)
targ2 = 25;


showex = 1; % Toggle to generate a set of single trial plots
showerr = 1; % Toggle to show parametric variation plots
showfoo = 1; % Toggle to show Fourier analysis plots

if ~exist(f1gdir,'dir')
    mkdir(f1gdir);
end

saveit = 1;
svgplot = 1;
visib = 'off';

SaccThresh = 0.5;
Ntrials = 5;

load([datafolder,'\metaparams']) 

plotsetC = zeros(4,2,2,200);

%% Errors and Saccade counts

if showerr
    
    errorsetCON = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    errorsetSCZ = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    
    vstdCON = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    vstdSCZ = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    
    pstdCON = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    pstdSCZ = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    
    saccCON = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    saccSCZ = zeros(Ntrials, Nmanip, Ntask,Nparvar);
    
    
    
    for trial = 1:Ntrials
        for manipidx = 1:Nmanip
            
            manip = manipset(manipidx);
            
            for parvar = 1:Nparvar
                switch manip
                    case 1
                        mstr = ['PV_',num2str(parvar)];
                    case 2
                        mstr = ['CB_',num2str(parvar)];
                    case 3
                        mstr = ['TRN_',num2str(parvar)];
                    case 4
                        mstr = ['STP_',num2str(parvar)];
                    case 5
                        mstr = ['PVx_',num2str(parvar)];
                    case 6
                        mstr = ['CBx_',num2str(parvar)];
                    case 7
                        mstr = ['Combo',num2str(parvar)];
                        
                    otherwise
                        mstr = 'Combo';
                end
                
                
                for tsk = 1:2
                    
                    datasetname = [datafolder,'/',mstr,'_trial',num2str(trial),'_task',num2str(tsk)];
                    load(datasetname,'cposs','tposs')
                    
                    errors = tposs - cposs;
                    
                    erCON = mean(errors(0.5*tlend+1:0.75*tlend).^2);
                    erSCZ = mean(errors(0.75*tlend+1:end).^2);
                    
                    errorsetCON(trial,manip,tsk,parvar) = sqrt(erCON);
                    errorsetSCZ(trial,manip,tsk,parvar) = sqrt(erSCZ);
                    
                    eyeVel = [0;  diff(cposs)];
                    
                    preSacc = sum(max(diff(sign(max(abs(eyeVel(0.5*tlend+1:0.75*tlend)) - SaccThresh,0))),0));
                    posSacc = sum(max(diff(sign(max(abs(eyeVel(0.75*tlend+1:tlend)) - SaccThresh,0))),0));
                    
                    saccCON(trial,manip,tsk,parvar) = preSacc;
                    saccSCZ(trial,manip,tsk,parvar) = posSacc;
                    
                    pstdCON(trial,manip,tsk,parvar) = std(cposs(0.5*tlend+1:0.75*tlend));
                    pstdSCZ(trial,manip,tsk,parvar) = std(cposs(0.75*tlend+1:tlend));
                    
                    vstdCON(trial,manip,tsk,parvar) = std(eyeVel(0.5*tlend+1:0.75*tlend));
                    vstdSCZ(trial,manip,tsk,parvar) = std(eyeVel(0.75*tlend+1:tlend));
                end
                
                
            end
        end
    end
    
    
    
    
    ff = figure('visible',visib,'Position',[10  10 scrsz(3)/4+600 0.9*scrsz(4)]);
    set(gcf,'color','w');
    
    
    
    CON = saccCON;
    SCZ = saccSCZ;
    minC = min(CON(:));
    maxS = max(SCZ(:));
    
    
    for tsk = 1:2
        
        for manipidx = 1:Nmanip
            manip = manipset(manipidx);
            
            switch manip
                case 1
                    parmanip = pvec1;
                case 2
                    parmanip = pvec1;
                case 3
                    parmanip = pvec2;
                case 4
                    parmanip = pvec1;
                case 5
                    parmanip = pvec4;
                case 6
                    parmanip = pvec1;
                case 7
                    parmanip = pvec1;
                otherwise
                    parmanip = pvec1;
            end
            
            
            
            if tsk == 1
                subplot(Nmanip,2,2*manipidx -1)
            else
                subplot(Nmanip,2,2*manipidx)
            end
            for i = 1:Ntrials
                
                plot(parmanip,squeeze(SCZ(i,manip,tsk,:)),'ro')
                hold on
            end
            
            
            avg = squeeze(SCZ(:,manip,tsk,:));
            baseline = squeeze(CON(:,manip,tsk,:));
            hold on
            plot(parmanip,mean(avg),'-kx','Linewidth',1)
            plot(parmanip,mean(baseline),'b--','Linewidth',1)
            errorbar(parmanip,mean(avg),std(avg),'-k')
            if manip ~=3
                set(gca, 'XDir','reverse')
                xlabel('Fraction of baseline strength')
            else
                
                xlabel('Inhibitory input')
            end
            title(['Task',num2str(tsk)])
            ylabel('no. of "sacc"')
            limsy=get(gca,'YLim');
            set(gca,'Ylim',[-5 limsy(2)]);
            
            
            if manip == 3
                set(gca,'Xlim',[0 90])
            end
            
        end
    end
    
    if saveit == 1
        tifname = [f1gdir,'/saccades.tif'];
        set(gcf, 'PaperUnits', 'inches');
        set(gcf, 'PaperPosition', [0 0 9 12]); %x_width=10cm y_width=15cm
        print('-dtiff','-r150',tifname)
        if svgplot == 1
            svgname = [f1gdir,'/saccades.svg'];
            print('-dsvg',svgname)
        end
        
    end
    
    
    ff = figure('visible',visib,'Position',[10  10 scrsz(3)/4+600 0.9*scrsz(4)]);
    set(gcf,'color','w');
    
    CON = errorsetCON;
    SCZ = errorsetSCZ;
    
    
    for tsk = 1:2
        
        for manipidx = 1:Nmanip
            manip = manipset(manipidx);
            switch manip
                case 1
                    parmanip = pvec1;
                case 2
                    parmanip = pvec1;
                case 3
                    parmanip = pvec2;
                case 4
                    parmanip = pvec1;
                case 5
                    parmanip = pvec4;
                case 6
                    parmanip = pvec1;
                case 7
                    parmanip = pvec1;
                otherwise
                    parmanip = pvec1;
            end
            if tsk == 1
                subplot(Nmanip,2,2*manipidx -1)
            else
                subplot(Nmanip,2,2*manipidx)
            end
            for i = 1:Ntrials
                
                
                plot(parmanip,squeeze(SCZ(i,manip,tsk,:)),'ro')
                hold on
            end
            
            %for p = 1:Nparvar
            avg = squeeze(SCZ(:,manip,tsk,:));
            baseline = squeeze(CON(:,manip,tsk,:));
            hold on
            plot(parmanip,mean(avg),'-kx','Linewidth',1)
            plot(parmanip,mean(baseline),'b--','Linewidth',1)
            errorbar(parmanip,mean(avg),std(avg),'-k')
            ylim([0 inf]);
            if manip ~=3
                set(gca, 'XDir','reverse')
                xlabel('Fraction of baseline strength')
            else
                
                xlabel('Inhibitory input')
            end
            ylabel('rms error')
            limsy=get(gca,'YLim');
            if tsk ==2
                set(gca,'Ylim',[-5 limsy(2)]);
            else
                set(gca,'Ylim',[1.8 limsy(2)]);
            end
            
            if manip == 3
                set(gca,'Xlim',[0 90])
            end
            title(['Task',num2str(tsk)])
            %if tsk == 1
            
            %hold on
            %boxplot(avg,p);
            
            
            
        end
    end
    
    if saveit == 1
        tifname = [f1gdir,'/errors.tif'];
        set(gcf, 'PaperUnits', 'inches');
        set(gcf, 'PaperPosition', [0 0 9 12]); %x_width=10cm y_width=15cm
        print('-dtiff','-r150',tifname)
        if svgplot == 1
            svgname = [f1gdir,'/errors.svg'];
            print('-dsvg',svgname)
        end
        
    end
    
end

%% Example trials

if showex
    
    trial = 1; %showing results for the 1st trial
    
    parvar = 5; %displaying the 5th parametric variation for each type of perturbation
    
    
    
    manipS = zeros(Nmanip,tlend);
    manipF = zeros(Nmanip,tlend);
    
    for manip = 1:4
        
        switch manip
            case 1
                parvar = 5; mstr = ['PV_',num2str(parvar)];
            case 2
                parvar = 5; mstr = ['CB_',num2str(parvar)];
            case 3
                parvar = 4; mstr = ['TRN_',num2str(parvar)];
            case 4
                parvar = 5; mstr = ['STP_',num2str(parvar)];
            case 5
                parvar = 3; mstr = ['PVx_',num2str(parvar)];
            case 6
                parvar = 4; mstr = ['CBx_',num2str(parvar)];
                
            otherwise
                parvar = 4; mstr = ['Combo',num2str(parvar)];
        end
        
        for tsk = 1:2
            
            datasetname = [datafolder,'/',mstr,'_trial',num2str(trial),'_task',num2str(tsk)];
            if tsk == 2
                tposs1 = tposs;
            end
            load(datasetname)
            if tsk == 1
                manipS(manip,:) = cposs;
            else
                manipF(manip,:) = cposs;
            end
            if manip == 1
                ff = figure('visible',visib,'Position',[10  10 scrsz(3)/4+600 0.9*scrsz(4)]);
                s1a = subplot(10,1,1);
                pos1a = get(s1a,'Position');
                plot(xxx,tposs,'Linewidth',2), hold on
                plot(xxx,cposs,'Linewidth',2)
                set(gca,'XTickLabel','')
                title('A: Tracking performance')
                ylabel('Position')
                if tsk == 1
                    
                    legend('Target','Eye Position','Location',[0.2 0.92 0.04 0.04])
                else
                    plot(xxx(0.25*length(xxx):end),targ2*ones(1,length(xxx(0.25*length(xxx):end))),'m','Linewidth',2)
                    
                    legend('Target','Eye Position','Distractor','Location',[0.2 0.92 0.04 0.04])
                    
                end
                set(s1a,'position',pos1a);
                
                subplot(10,1,2)
                plot(xxx,errors,'Linewidth',2)
                set(gca,'XTickLabel','')
                title('B: Relative position of eye with respect to target')
                ylabel('Relative position')
                axis([0 durat -30 30])
                
                s1 = subplot(10,1,3);
                [tt,ff,pp] = spectro_gen(y,durat);
                hh = imagesc(tt,ff,log(pp));
                %             hold on
                %             dline = 10*ones(length(tt),1);
                %
                %             plot(tt,dline,'.b')
                
                axis xy
                axis([0 durat 0 100])
                
                ylabel('Freq (Hz)')
                title('C: Spectrogram of total superf1cial cortical activity')
                pos1 = get(s1,'Position');
                hcb = colorbar('location','eastoutside');
                
                set(s1,'position',pos1);
                ylabel(hcb, 'log power')
                set(gca,'XTickLabel','')
                
                toplot = syn1s;
                
                s1a = subplot(10,1,5);
                rasterPlot(vs(ctxD,:),durat)
                title('E: Raster plot: DLNs')
                ylabel('Neuron #')
                set(gca,'XTickLabel','')
                
                s2 = subplot(10,1,4);
                rasterPlot(vs(ctxS,:),durat)
                
                title('D: Raster plot: MLNs')
                ylabel('Neuron #')
                set(gca,'XTickLabel','')
                
                s3 = subplot(10,1,6);
                rasterPlot(vs(cPVS,:),durat)
                title('F: Raster plot: PV-INs')
                set(gca,'XTickLabel','')
                ylabel('Neuron #')
                
                s3a = subplot(10,1,7);
                rasterPlot(vs(cCBS,:),durat)
                title('G: Raster plot: CB-INs')
                set(gca,'XTickLabel','')
                ylabel('Neuron #')
                
                s4 = subplot(10,1,8);
                rasterPlot(vs(trnS,:),durat)
                title('H: Raster plot: TRN')
                ylabel('Neuron #')
                set(gca,'XTickLabel','')
                
                s5 = subplot(10,1,9);
                rasterPlot(vs(thaS,:),durat)
                title('I: Raster plot: Thalamus')
                set(gca,'XTickLabel','')
                ylabel('Neuron #')
                
                s6 = subplot(10,1,10);
                imagesc(xxx,yyy1,randInp(thaS,:))
                axis xy
                title('J: External thalamic input')
                ylabel('Neuron #')
                pos6 = get(s6,'Position');
                hcb = colorbar('location','eastoutside');
                set(s6,'position',pos6);
                xlabel('Time (s)')
                
                if saveit == 1
                    tifname = [f1gdir,'/',mstring,'_aseed_',num2str(seed),'_task',num2str(tsk),'manip_',mstr,'.tif'];
                    set(gcf, 'PaperUnits', 'inches');
                    set(gcf, 'PaperPosition', [0 0 9 12]); %x_width=10cm y_width=15cm
                    print('-dtiff','-r150',tifname)
                    if svgplot == 1
                        svgname = [f1gdir,'/',mstring,'_aseed_',num2str(seed),'_task',num2str(tsk),'manip_',mstr,'.svg'];
                        print('-dsvg',svgname)
                    end
                end
            else
                if tsk == 1
                    ff = figure('visible',visib,'Position',[10  10 scrsz(3)/4+600 0.9*scrsz(4)]);
                end
                set(gcf,'color','w');
                
                s1a = subplot(10,2,1+(tsk-1));
                pos1a = get(s1a,'Position');
                plot(xxx,tposs,'Linewidth',2), hold on
                plot(xxx,cposs,'Linewidth',2)
                set(gca,'XTickLabel','')
                title('Tracking performance')
                ylabel('Position')
                if tsk == 1
                    
                    legend('Target','Eye Position','Location',[0.44 0.92 0.04 0.04])
                else
                    plot(xxx(0.25*length(xxx):end),targ2*ones(1,length(xxx(0.25*length(xxx):end))),'m','Linewidth',2)
                    
                    legend('Target','Eye Position','Distractor','Location',[0.88 0.92 0.04 0.04])
                    
                end
                
%                 hold on
%                 eyeVel = [0  diff(cposs)];
%                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
%                 plot(xxx,5*sacclike','-k');
                
                
                set(s1a,'position',pos1a);
                axis([durat/2 durat 0 40])
                
                
                subplot(10,2,3+(tsk-1))
                plot(xxx,errors,'Linewidth',2)
                set(gca,'XTickLabel','')
                title('Relative position of eye with respect to target')
                ylabel('Relative position')
                axis([durat/2 durat -30 30])
                
                s1 = subplot(10,2,5+(tsk-1));
                [tt,ff,pp] = spectro_gen(y,durat);
                hh = imagesc(tt,ff,log(pp));
                axis xy
                axis([durat/2 durat 0 100])
                
                ylabel('Freq (Hz)')
                title('Spectrogram of total superf1cial cortical activity')
                pos1 = get(s1,'Position');
                hcb = colorbar('location','eastoutside');
                
                cbx1=get(gca,'position');
                cbx=get(hcb,'Position');
                %set(hcb,'Units','normalized')
                cbx(3)=0.01;
                cbx(1)=cbx1(1)+1.02*cbx1(3);
                set(hcb,'Position',cbx)
                set(gca,'position',cbx1)
                set(s1,'position',pos1);
                ylabel(hcb, 'log power')
                set(gca,'XTickLabel','')
                
                
                toplot = syn1s;
                
                s2 = subplot(10,2,7+(tsk-1));
                rasterPlot(vs(ctxS,:),durat)
                title('Raster plot: MLNs')
                ylabel('Neuron #')
                set(gca,'XTickLabel','')
                axis([durat/2 durat 0 120])
                
                s1a = subplot(10,2,9+(tsk-1));
                rasterPlot(vs(ctxD,:),durat)
                title('Raster plot: DLNs')
                ylabel('Neuron #')
                set(gca,'XTickLabel','')
                axis([durat/2 durat 0 120])
                
                
                s3 = subplot(10,2,11+(tsk-1));
                rasterPlot(vs(cPVS,:),durat)
                title('Raster plot: PV-INs')
                set(gca,'XTickLabel','')
                ylabel('Neuron #')
                axis([durat/2 durat 0 40])
                
                s3a = subplot(10,2,13+(tsk-1));
                rasterPlot(vs(cCBS,:),durat)
                title('Raster plot: CB-INs')
                set(gca,'XTickLabel','')
                ylabel('Neuron #')
                axis([durat/2 durat 0 40])
                
                s4 = subplot(10,2,15+(tsk-1));
                rasterPlot(vs(trnS,:),durat)
                title('Raster plot: TRN')
                ylabel('Neuron #')
                set(gca,'XTickLabel','')
                axis([durat/2 durat 0 40])
                
                s5 = subplot(10,2,17+(tsk-1));
                rasterPlot(vs(thaS,:),durat)
                title('Raster plot: Thalamus')
                set(gca,'XTickLabel','')
                ylabel('Neuron #')
                axis([durat/2 durat 0 40])
                
                s6 = subplot(10,2,19+(tsk-1));
                imagesc(xxx,yyy1,randInp(thaS,:))
                axis xy
                axis([durat/2 durat 0 40])
                
                title('External thalamic input')
                ylabel('Neuron #')
                pos6 = get(s6,'Position');
                hcb = colorbar('location','eastoutside');
                set(s6,'position',pos6);
                xlabel('Time (s)')
                cbx1=get(gca,'position');
                cbx=get(hcb,'Position');
                %set(hcb,'Units','normalized')
                cbx(3)=0.01;
                cbx(1)=cbx1(1)+1.02*cbx1(3);
                set(hcb,'Position',cbx)
                set(gca,'position',cbx1)
                
                
                if tsk == 2
                    
                    if saveit == 1
                        tifname = [f1gdir,'/',mstring,'_aseed_',num2str(seed),'_task',num2str(tsk),'manip_',mstr,'.tif'];
                        set(gcf, 'PaperUnits', 'inches');
                        set(gcf, 'PaperPosition', [0 0 9 12]); %x_width=10cm y_width=15cm
                        print('-dtiff','-r150',tifname)
                        
                        if svgplot == 1
                            svgname = [f1gdir,'/',mstring,'_aseed_',num2str(seed),'_task',num2str(tsk),'manip_',mstr,'.svg'];
                            print('-dsvg',svgname)
                        end
                    end
                end
            end
            
            
        end
        
    end
    
    
    faf = figure('visible',visib,'Position',[10  10 scrsz(3)/4+600 0.9*scrsz(4)]);
    set(gcf,'color','w');
    subplot(421)
    plot(timevec2(0.5*tlend:end),manipS(1,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs1(0.5*tlend:end),'b','Linewidth',2)
    

                 eyeVel = [0  diff(manipS(1,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    
    
    title('A: PV-IN perturbation')
    axis([4 8 0 40])
    subplot(423)
    plot(timevec2(0.5*tlend:end),manipS(2,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs1(0.5*tlend:end),'b','Linewidth',2)
                 hold on
                 eyeVel = [0  diff(manipS(2,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');

    
    
    title('B: CB-IN perturbation')
    axis([4 8 0 40])
    subplot(425)
    plot(timevec2(0.5*tlend:end),manipS(3,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs1(0.5*tlend:end),'b','Linewidth',2)
                     hold on
                 eyeVel = [0  diff(manipS(3,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    title('C: TRN perturbation')
    axis([4 8 0 40])
    
    subplot(427)
    plot(timevec2(0.5*tlend:end),manipS(4,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs1(0.5*tlend:end),'b','Linewidth',2)
                     hold on
                 eyeVel = [0  diff(manipS(4,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    title('D: dSTP perturbation')
    axis([4 8 0 40])
    xlabel('Time (s)')
    
    subplot(422)
    plot(timevec2(0.5*tlend:end),manipF(1,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs(0.5*tlend:end),'b','Linewidth',2)
    plot(timevec2(0.5*tlend:end),targ2*ones(1,length(tposs(0.5*tlend:end))),'m','Linewidth',2)
                     hold on
                 eyeVel = [0  diff(manipF(1,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    title('E: PV-IN perturbation')
    axis([4 8 0 40])
    subplot(424)
    plot(timevec2(0.5*tlend:end),manipF(2,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs(0.5*tlend:end),'b','Linewidth',2)
    plot(timevec2(0.5*tlend:end),targ2*ones(1,length(tposs(0.5*tlend:end))),'m','Linewidth',2)
                     hold on
                 eyeVel = [0  diff(manipF(2,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    title('F: CB-IN perturbation')
    axis([4 8 0 40])
    subplot(426)
    plot(timevec2(0.5*tlend:end),manipF(3,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs(0.5*tlend:end),'b','Linewidth',2)
    plot(timevec2(0.5*tlend:end),targ2*ones(1,length(tposs(0.5*tlend:end))),'m','Linewidth',2)
                     hold on
                 eyeVel = [0  diff(manipF(3,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    title('G: TRN perturbation')
    axis([4 8 0 40])
    
    subplot(428)
    plot(timevec2(0.5*tlend:end),manipF(4,0.5*tlend:end),'r','Linewidth',2)
    hold on
    plot(timevec2(0.5*tlend:end),tposs(0.5*tlend:end),'b','Linewidth',2)
    plot(timevec2(0.5*tlend:end),targ2*ones(1,length(tposs(0.5*tlend:end))),'m','Linewidth',2)
                     hold on
                 eyeVel = [0  diff(manipF(4,0.5*tlend:end))];
                 sacclike = [0  max(diff(sign(max(abs(eyeVel) - SaccThresh,0))),0)];
                 plot(timevec2(0.5*tlend:end),5*sacclike,'-k');
    title('H: dSTP perturbation')
    axis([4 8 0 40])
    xlabel('Time (s)')
    
    tifname = [f1gdir,'/',mstring,'_aseed_',num2str(seed),'compar','.tif'];
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperPosition', [0 0 9 12]); %x_width=10cm y_width=15cm
    print('-dtiff','-r150',tifname)
    if svgplot == 1 && saveit == 1
        svgname = [f1gdir,'/',mstring,'_aseed_',num2str(seed),'compar','.svg'];
        print('-dsvg',svgname)
    end
    
    
    
    
end


if showfoo
    
    trial = 1;
    
    parvar = 5;
         

    for manip = 1:4
        
        switch manip
            case 1
                parvar = 5; mstr = ['PV_',num2str(parvar)];
            case 2
                parvar = 5; mstr = ['CB_',num2str(parvar)];
            case 3
                parvar = 4; mstr = ['TRN_',num2str(parvar)];
            case 4
                parvar = 5; mstr = ['STP_',num2str(parvar)];
            case 5
                parvar = 3; mstr = ['PVx_',num2str(parvar)];
            case 6
                parvar = 4; mstr = ['CBx_',num2str(parvar)];
                
            otherwise
                parvar = 4; mstr = ['Combo',num2str(parvar)];
        end
        
        for tsk = 1:2
            
            datasetname = [datafolder,'/',mstr,'_trial',num2str(trial),'_task',num2str(tsk)];

            load(datasetname,'y')

            [p1,p2,f1] = fourierComp(y(0.5*tlend+1:0.75*tlend),y(0.75*tlend+1:end),durat/4);

            flength = min(200,length(p1));
            frange = 1:flength;
            plotsetC(manip,tsk,1,frange) = p1(frange);
            plotsetC(manip,tsk,2,frange) = p2(frange);
        end
    end
    
    faf = figure('visible',visib,'Position',[10  10 scrsz(3)/4+600 0.9*scrsz(4)]);
    set(gcf,'color','w');
    
    
    
    subplot(421)
    plot(f1(frange),squeeze(plotsetC(1,1,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(1,1,2,1:flength)))
    
    
    ylim([0 510])    
    legend('Normal','Perturbed')
    title('A: PV-IN perturbation')
   
    subplot(423)
    plot(f1(frange),squeeze(plotsetC(2,1,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(2,1,2,1:flength)))
    ylim([0 510])    
    legend('Normal','Perturbed')
    title('B: CB-IN perturbation')
   
    subplot(425)
    plot(f1(frange),squeeze(plotsetC(3,1,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(3,1,2,1:flength)))
    ylim([0 510])    
    legend('Normal','Perturbed')
    title('C: TRN perturbation')
    
    subplot(427)
    plot(f1(frange),squeeze(plotsetC(4,1,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(4,1,2,1:flength)))
   ylim([0 510])    
   legend('Normal','Perturbed')
    title('D: dSTP perturbation')
    xlabel('Frequency (Hz)')
    subplot(422)
    plot(f1(frange),squeeze(plotsetC(1,2,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(1,2,2,1:flength)))
    ylim([0 510])    
    legend('Normal','Perturbed')
    title('E: PV-IN perturbation')
    
    subplot(424)
    plot(f1(frange),squeeze(plotsetC(2,2,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(2,2,2,1:flength)))    
    ylim([0 510])    
legend('Normal','Perturbed')
    title('F: CB-IN perturbation')
    
    subplot(426)
    plot(f1(frange),squeeze(plotsetC(3,2,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(3,2,2,1:flength)))    
    ylim([0 510])    
    legend('Normal','Perturbed')
    title('G: TRN perturbation')
    
    subplot(428)
    plot(f1(frange),squeeze(plotsetC(4,2,1,1:flength)))
    hold on
    plot(f1(frange),squeeze(plotsetC(4,2,2,1:flength)))    
    ylim([0 510])    
    legend('Normal','Perturbed')
    title('H: dSTP perturbation')
    xlabel('Frequency (Hz)')
    
        tifname = [f1gdir,'/Foo','.tif'];
    set(gcf, 'PaperUnits', 'inches');
    set(gcf, 'PaperPosition', [0 0 9 12]); %x_width=10cm y_width=15cm
    print('-dtiff','-r150',tifname)
    if svgplot == 1 && saveit == 1
        svgname = [f1gdir,'/FourierPlot','.svg'];
        print('-dsvg',svgname)
    end
    
end

