clear all
heavi = @(x) sign(max(x,0));
mstring = mfilename;

saveData = 1; %To save figures and/or mfile in a folder
saveAllFigs = 1; %To plot figures for each trial simulation
svgflag = 0; %To generate svg files in addition to tifs

if saveData == 1;
    
    close all
    visib = 'off';
    formatOut = 'yyyy-mm-dd-HHMM';
    dstr = datestr(datetime('now'),formatOut);
    dirstring = [mfilename,'_',dstr];
    mkdir(dirstring); %Creates a folder with data and time, which will contain figures and this mfile
else
    visib = 'on';    
end

if saveData == 1
    copyfile([mstring,'.m'],dirstring)
    imgtype = 'tif';
end

Ntrials = 2;
%Perturbation amounts
pvec1 = [0.5 0.4 0.3 0.2 0.1]; 
pvec2 = [15 30 45 60 75];
pvec4 = [0.9 0.8 0.7 0.6 0.5];
pvec3 = pvec2;

Nparvar = length(pvec1); %Number of parametric variations per perturbation
manipset = [1 2 3 4 5 6 7]; %Set of manipulations to run
Nmanip = length(manipset);
tskset = [1 2]; 
Ntask = length(tskset);


%% Timestep parameters
durat = 1; % duration of each trial, in seconds. In published figures, duration is 8 seconds.
downsamp = 100; stepspersecond = 40000;
tlen = durat*stepspersecond;
tlend = tlen/downsamp;
timevec = linspace(0,durat,tlen); h = timevec(2); hz = 1000*h; timevec2 = linspace(0,durat,tlend);
tfra = 0.75; % fraction of trial period at which perturbation occurs


if saveData==1
   save([dirstring,'/metaparams']) 
end
%% Neuron groups
fac = 3; %scaling factor for number of cortical neurons
Na = 40; % number of thalamic and TRN neurons
NaC = Na*fac; % number of cortical neurons
NaPV = Na; %number of PV interneurons
NaCB = Na; %number of CB interneurons

NperRegion = [Na Na NaC NaPV NaCB NaC];
Nregions = length(NperRegion);
regionindex = zeros(Nregions,2);

regionindex(1,1) = 1;
regionindex(1,2) = NperRegion(1);

for ii = 2:Nregions
    regionindex(ii,1) = 1 + regionindex(ii-1,2);
    regionindex(ii,2) = regionindex(ii-1,2) + NperRegion(ii);
end

N = sum(NperRegion); %Total number of neurons

% indices of each neuron group
thaS = regionindex(1,1):regionindex(1,2);
trnS = regionindex(2,1):regionindex(2,2);
ctxS = regionindex(3,1):regionindex(3,2);
cPVS = regionindex(4,1):regionindex(4,2);
cCBS = regionindex(5,1):regionindex(5,2);
ctxD = regionindex(6,1):regionindex(6,2);


%% EPSPs and IPSPs

Ninp = N;
inpidx = (N+1):(N+Ninp);

epsp = zeros(N,1);
epsps = zeros(N,tlend);

spik = zeros(N+Ninp,1);
spiker = zeros(N+Ninp,1);
syn1 = zeros(N+Ninp,1);
syn2 = zeros(N+Ninp,1);
syn3 = zeros(N+Ninp,1);
spik1 = zeros(N+Ninp,1);
spik2 = zeros(N+Ninp,1);
spik3 = zeros(N+Ninp,1);

syn1s = zeros(N,tlend);
syn2s = zeros(N,tlend);
syn3s = zeros(N,tlend);
AMPAs = zeros(N,tlend);
NMDAs = zeros(N,tlend);
GABAAs = zeros(N,tlend);
Ie=zeros(N,1);
Ii=zeros(N,1);
Ies = zeros(N,tlend);
Iis = zeros(N,tlend);




%% External inputs


extInp = zeros(N,tlend);
%randI = extInp;

fmax =250;
fmin = 30;

finp = zeros(Ninp,1);
envelC = 0;

inp = zeros(N,1);
Igap = zeros(Na,1);
Iinh = zeros(N,1);



%%
tNMDA = 1;
tAMPA = 1;
%% Calcium current
IT = zeros(N,1);
ITs = zeros(N,tlend);

F = 95484.56; R = 8.314; T = 298; PP = 30e-6;
ITconst1 = PP*4*F*F/(R*T); ITconst2 = 2*F/(R*T);
CaI = 50e-9; CaE = 2e-3;
VH1 = -90; VH2 = -90; kH1 = 5; kH2 = 13; aHH = 900; VH = -45;
uu = zeros(N,1);
ss = zeros(N,1);
Ca = zeros(N,1);

Cas = zeros(N,tlend);
sss = zeros(N,tlend);
uus = zeros(N,tlend);

gIT = 1000;


%TLT
tuF =@(V) (30.8 +(211.4+exp((V+115.2)./5))./((1+exp((V+86)./3.2))))/3.737;
tsF = @(V) 0.999 + 0.333./(exp((V+27)./10) + exp(-(V+102)/15));
sinfF = @(V) 1./(1+exp(-(V+75)./6.2));
uinfF = @(V) 1./(1+exp((V+88)./4));
Vsh = 4; % voltage shift necessitated by use of Izhikevich neurons


%% Tracking
cpos = Na/2; % position of model eye in absolute coordinates
cposs = zeros(tlend,1);
tposs = zeros(tlend,1); % position of target in absolute coordiantes
errors = zeros(tlend,1);

manipS = zeros(Nmanip,tlend);
manipF = zeros(Nmanip,tlend);

moveW = zeros(2,NaC);
moveW(1,1:NaC/2) = 0.5*(NaC/2:-1:1)/(NaC/2);
moveW(2,NaC/2+1:NaC) = 0.5*(1:NaC/2)/(NaC/2);

errorW = (1-exp(-((NaC/2-(1:NaC))/15).^2));
errorSigs = zeros(tlend,1);
movemag = 0.05;

% bounds of sinusoidal stimulus for smooth tracking
ext1 = 11;  
ext2 = 30;

envelw = 4; % width of target and distractor


%% Trials

for trial = 1:Ntrials;
    
    rrr = 400+trial; % seed for random number generation
    seed = rrr; rng(seed); disp(['RNG seed = ',num2str(seed)]);
    
    %% Weights and related parameters
    WTR = uWmap(Na,Na,0.15*(25/Na)); % thalamus to TRN
    WCR = uWmap(NaC,Na,0.02*(25/Na)); % amplitude of DLNs to TRN eights
    sWSTC = 40; %amplitude of thalamus to MLNs wights
    sWSCT = 4; %amplitude of DLNs to thalamus weights
    
    WCP = uWmap(NaC,Na,0.04*(25/Na)); %MLNs to PVINs
    WCCB = uWmap(NaC,Na,0.2*(25/Na)); %MLNs to CBINs
    Wgap = uWmap(Na,Na,0.05.*(25/Na)); %gap junction coupling among TRN neurons
    Wgap(logical(eye(Na))) = 0;
    
    WtrnthalS = ones(Na); % all-to-all connectivity from TRN to thalamus
    
    wRand = zeros(17,1);
    wMod = ones(17,1)+wRand; % used for testing robustness of parameters
    
    kk = 1;
    
    sWSCR = wMod(kk); kk = kk+1; %% kk is the index of parameters
    sWSTR = 0.15.*wMod(kk); kk = kk+1; %amplitude of thalamus to TRN weights
    sWtrnthaSA = 8.*wMod(kk); kk = kk+1; %amplitude of TRN to thalamus weights
    
    WTC = 0.12*uWmap(Na,NaC,0.1*(25*3/NaC)).*wMod(kk); kk = kk+1; % thalamus to MLNs proximal
    WTCd = 0.03*(uWmap(Na,NaC,1.5*(25*3/NaC))).*wMod(kk); kk = kk+1; % thalamus to MLNs distal
    WCT = 0.01*uWmap(NaC,Na,0.08*(25/Na)).*wMod(kk); kk = kk+1; %DLNs to thalamus
    WCTb = 0.01*uWmap(NaC,Na,0.08*(25/Na)).*wMod(kk); kk = kk+1; %DLNs to thalamus (for dSTP)
    
    WPC = 50*uWmap(Na,NaC,0.7*(25*3/NaC)).*wMod(kk); kk = kk+1; %PVINs to MLNs
    
    WPP = 10*uWmap(NaPV,NaPV,0.05.*(25/NaPV)).*wMod(kk); kk = kk+1; %PVINs to PVINs
    
    WCB = 0.025*(uWmap(NaCB,NaC,2*(25*3/NaC))).*wMod(kk); kk = kk+1; %CBINs to MLNs distal
    WSD = 1.4*uWmap(NaC,NaC,0.02*(25*3/NaC)).*wMod(kk); kk = kk+1; %MLNs to DLNs
    WSTPInit = 3000.*wMod(kk); kk = kk+1; %Strength of dSTP factor
    
    gGAP = 0.30.*wMod(kk); kk = kk+1; %amplitude of gap junction coupling
    
    PVinpInit = 0.5.*wMod(kk); kk = kk+1; % initial AMPA input to PVINs
    PVinp2Init = 4.*wMod(kk); kk = kk+1; %initial NMDA input to PVINs
    CBinpInit = 0.03.*wMod(kk); kk = kk+1; %initial AMPA input to CBINs
    CBinp2Init = 1.*wMod(kk); %initial NMDA input to CBINs
    gabB = 0.04; % strength of GABA-B TRN-thalamus synapse 
    
    
    %% Izhikevich variables and constants
    SpkRand = 0.1;  % plus/minus 5% variability in spiking neuron parameters
    disp(num2str(SpkRand))
    
    pset = [];
    
    pset = ParSet_Izh(1,N,pset,1:N,'RS2',SpkRand); 
    pset = ParSet_Izh(0,N,pset,cPVS,'FS',SpkRand);
    
    a= pset.a; b= pset.b; c= pset.c; d= pset.d;
    
    vs = zeros(N,tlend);
    vInit = -65.*(1+SpkRand.*(rand(N,1)-0.5));  % Initial values of v
    
    
    
    %% Time constants initialization
    
    tau1r = 2.*(1+SpkRand.*(rand(N+Ninp,1)-0.5));
    tau1f = 10.*(1+SpkRand.*(rand(N+Ninp,1)-0.5));
    tau2r = 8.*(1+SpkRand.*(rand(N+Ninp,1)-0.5));
    tau2f = 100.*(1+SpkRand.*(rand(N+Ninp,1)-0.5));
    tau3r = 200.*(1+SpkRand.*(rand(N+Ninp,1)-0.5));
    tau3f = 400.*(1+SpkRand.*(rand(N+Ninp,1)-0.5));
    
    tau1r(cPVS) = 0.1.*(1+SpkRand.*(rand(length(cPVS),1)-0.5));
    tau1f(cPVS) = 0.5.*(1+SpkRand.*(rand(length(cPVS),1)-0.5));
    
    tau2r(trnS) = 8.*(1+SpkRand.*(rand(length(trnS),1)-0.5));
    tau2f(trnS) = 30.*(1+SpkRand.*(rand(length(trnS),1)-0.5));%
    
    
    
    %% Integration
    
    
    for manipidx = 1:Nmanip  % Loop for manipulations (perturbations)
        manip = manipset(manipidx);
        for tskidx = 1:Ntask % Loop for tasks (smooth pursuit and fixation)
            tsk = tskset(tskidx);
            
            if Nparvar>1  %for parametric variation
                switch manip
                    case 1
                        parmanip = pvec1;
                    case 2
                        parmanip = pvec1;
                    case 3
                        parmanip = pvec2;
                    case 4
                        parmanip = pvec1;
                    case 5
                        parmanip = pvec4;
                    case 6
                        parmanip = pvec1;
                    case 7
                        parmanip = pvec1;
                    otherwise
                        parmanip = pvec1;
                end
                
            else
                switch manip % for single example 
                    case 1
                        parmanip = 0.2;
                    case 2
                        parmanip = 0.2;
                    case 3
                        parmanip = 60;
                    case 4
                        parmanip = 0.2;
                    case 5
                        parmanip = 0.6;
                    case 6
                        parmanip = 0.2;
                    otherwise
                        parmanip = 0.2;
                end
            end
            
            for parvar = 1:Nparvar
                % initialiations
                tic
                st = 1;
                
                PVinp = PVinpInit;
                PVinp2 = PVinp2Init;
                CBinp = CBinpInit;
                CBinp2 = CBinp2Init;
                WSTP = WSTPInit;
                
                if parvar ==1
                    v= vInit;    % Initial values of v
                    u=b.*v;
                                        
                    spik1 = 0.*spik1;
                    spik2 = 0.*spik2;
                    spik3 = 0.*spik3;
                    
                    syn1 = 0.*syn1;
                    syn2 = 0.*syn2;
                    syn3 = 0.*syn3;
                    Iinh = 0.*Iinh;
                    Igap = 0.*Igap;
                    uu = 0.*uu;
                    ss = 0.*ss;
                    Ca = 0.*Ca;
                    tInit = 1;
                    cpos = 8;
                else
                    
                    v = vR;
                    u = uR;
                    
                    spik1 = spik1R;
                    spik2 = spik2R;
                    spik3 = spik3R;
                    
                    syn1 = syn1R;
                    syn2 = syn2R;
                    syn3 = syn3R;
                    Iinh = IinhR;
                    Igap = IgapR;
                    uu = uuR;
                    ss = ssR;
                    Ca = CaR;
                    cpos = cposR;
                    tInit = tfra*tlen;
                    st = tfra*tlen/downsamp;
                end
                                                                                             
                rng(seed); % for reproducibility 
                gAPV = 1;
                gACB = 1;
                
                for t = tInit:tlen %integration loop
                    
                    if tsk == 1
                        targ = (ext1+(ext2-ext1).*0.5.*(1+sin(2*pi*timevec(t)))); %smooth pursuit sinusoid
                        tposs(st) = targ;
                        relpos = targ - cpos;
                        envel = exp(-(((-(Na/2-1):Na/2)-relpos)/envelw).^2);
                    else
                        targ = 10; %target location
                        tposs(st) = targ;
                        relpos = targ - cpos;
                        envel = exp(-(((-(Na/2-1):Na/2)-relpos)/envelw).^2);
                        if t>0.25*tlen
                            targ2 = 25; %distractor location
                            relpos2 = targ2 -cpos;
                            envel = (exp(-(((-(Na/2-1):Na/2)-relpos)/envelw).^2) + exp(-(((-(Na/2-1):Na/2)-relpos2)/envelw).^2));
                        end
                    end
                    
                    % perturbations
                    if t==tfra*tlen && manip == 3
                        Iinh(trnS) = parmanip(parvar);
                    end
                    
                    if t==tfra*tlen && manip == 2
                        CBinp2 = parmanip(parvar).*CBinp2Init; %1.4
                        
                    end
                    
                    if t==tfra*tlen && manip == 1
                        PVinp2 = parmanip(parvar).*PVinp2Init; %1.4                     
                    end
                    
                    
                    if t==tfra*tlen && manip == 4                        
                        WSTP = parmanip(parvar).*WSTPInit;
                    end
                    
                    
                    if t==tfra*tlen && manip == 5
                        gAPV = parmanip(parvar);
                    end
                    
                    if t==tfra*tlen && manip == 6
                        gACB = parmanip(parvar);
                    end
                    
                    if t==tfra*tlen && manip == 7
                        CBinp2 = parmanip(parvar);
                        PVinp2 = parmanip(parvar).*PVinp2Init; %1.4
                    end
                    
                    if t == tfra*tlen -1
                        vR= v;    % Initial values of v
                        uR= u;
                        
                        spik1R = spik1;
                        spik2R = spik2;
                        spik3R = spik3;
                        
                        syn1R = syn1;
                        syn2R = syn2;
                        syn3R = syn3;
                        IinhR = Iinh;
                        IgapR = Igap;
                        uuR = uu;
                        ssR = ss;
                        CaR = Ca;
                        cposR = cpos;
                    end
                    
                    
                    envel = fmin + (fmax-fmin)*envel./max(envel); % Poisson rate envelope for thalamic input
                    
                    poi = N+find(h*(envel')> rand(Na,1)); % Poisson inputs
                    
                    mv = moveW*max(syn1(ctxS),0); % Movement signal
                    
                    err = mv(1) - mv(2);
                    errorSigs(st) = errorW*syn1(ctxS);
                    
                    cpos = cpos - movemag*err; %shifting the model eye
                    cpos = min(cpos,36);
                    cpos = max(cpos,5);
                    cposs(st) = cpos;
                    errors(st) = relpos;
                    
                    % calcium dynamics
                    V = v;
                    CaI = Ca;
                    sinf = sinfF(V+Vsh);
                    uinf = uinfF(V+Vsh);
                    ts = tsF(V+Vsh);
                    tu = tuF(V+Vsh);
                    IT = gIT.*ITconst1*ss.*ss.*uu.*(V/1000).*((CaI-CaE*exp(-ITconst2.*V/1000))./(1-exp(-ITconst2.*V/1000)));
                    VZflag = V==0;
                    IT(VZflag) = gIT*PP*2*F*(CaI(VZflag)-CaE);
                    ITs(:,st) = IT;
                    
                    Ca = Ca +hz.*(max(-10.*IT./(2*96485.3),0) - 0.2*(Ca - 0.00024));
                    
                    
                    uu = uu+ hz.*(uinf - uu)./(tu);
                    ss = ss+ hz.*(sinf - ss)./(ts);
                    sss(:,st) = ss;
                    uus(:,st) = uu;
                    
                    % glutamatergic currents
                    AMPA = -v;
                    
                    gNMDA = 1./(1+exp(-.062*v)*1.5/3.57); %Methods in Neuronal Modeling
                    NMDA = -v.*gNMDA;
                    
                    GABAA = (v+70);
                    GABAB = (v+90);
                    
                    % excitatory inputs to each neuron group
                    inp(thaS) = (tAMPA*AMPA(thaS).*syn1(inpidx(thaS))...
                        + tNMDA*NMDA(thaS).*syn2(inpidx(thaS)));
                    
                    
                    inp(ctxD) = AMPA(ctxD).*(WSD*syn1(ctxS));
                    
                    Igap = -gGAP*sum(Wgap.*(V(trnS,1)*ones(1,Na) -ones(Na,1)*V(trnS)'),2);
                    
                    Ie(thaS) = sWSCT*AMPA(thaS).*(WCT*syn1(ctxD)) ...
                        +  inp(thaS)...
                        - 20*IT(thaS) ;
                    Ie(trnS) = inp(trnS) ...
                        + sWSCR*AMPA(trnS).*(WCR*syn1(ctxD)) ...
                        + sWSTR*AMPA(trnS).*(WTR*syn1(thaS)) ...
                        - 12*IT(trnS) ...
                        + Igap;
                    
                    cInp1 = sWSTC*AMPA(ctxS).*(WTC*syn1(thaS) ...
                        + max(WTCd*syn1(thaS) - gACB.*WCB*syn1(cCBS),0));
                    
                    Ie(ctxD) = inp(ctxD);
                    
                    Ie(ctxS) = cInp1;
                    
                    Ie(cPVS) = PVinp.*AMPA(cPVS).*(WCP*syn1(ctxS)) ...
                        + PVinp2*NMDA(cPVS).*(WCP*syn2(ctxS));% ...
                    
                    Ie(cCBS) = CBinp.*AMPA(cCBS).*(WCCB*syn1(ctxS)) ...
                        + CBinp2.*NMDA(cCBS).*(WCCB*syn2(ctxS));
                    
                    % inhibitory inputs to each neuron group
                    
                    Ii(thaS) = (gabB./(1+WSTP*WCTb*(syn3(ctxD)).^6)).*sWtrnthaSA.*GABAB(thaS).*(WtrnthalS*syn2(trnS)) ;
                    
                    %variant forms (may need to be adjusted to get similar behaviors for all perturbations):
                    
                    %Ii(thaS) = (gabB./(1+0.05*WSTP*WCTb*max(syn3(ctxD)-0.1,0))).*sWtrnthaSA.*GABAB(thaS).*(WtrnthalS*syn2(trnS)) ;
                    
                    %Ii(thaS) = max(gabB.*sWtrnthaSA.*GABAB(thaS).*(WtrnthalS*syn2(trnS)) - 0.15*WSTP*WCTb*syn3(ctxD),0) ;
                    %Ii(thaS) = max(gabB.*sWtrnthaSA.*GABAB(thaS).*(WtrnthalS*syn2(trnS)) - 0.04*WSTP*WCTb*(syn3(ctxD)),0) ;
                    
                    Ii(ctxS) =   gAPV.*GABAA(ctxS).*(WPC*syn1(cPVS));
                    Ii(cPVS) =   gAPV.*GABAA(cPVS).*(WPP*syn1(cPVS));
                    
                    % Izhikevich neuron dynamics
                    
                    fired=find(v>=30);    % indices of spikes
                    
                    v(fired)=c(fired);
                    u(fired)=u(fired)+d(fired);
                    
                    tInp = Ie -Ii-Iinh;
                    
                    v=v+hz*(0.04*v.^2+5*v+140-u+tInp);
                    u=u+hz.*a.*(b.*v-u);
                    
                    spiker = 0.*spiker;
                    fired = [fired; poi];%;poiC; poiCB];
                    spiker(fired) = 1;
                    
                    % saturating differentials synaptic dynamics
                    
                    spik1 = spik1 + hz.*((1-spik1).*spiker - spik1./tau1r);
                    spik2 = spik2 + hz.*((1-spik2).*spiker - spik2./tau2r);
                    spik3 = spik3 + hz.*((1-spik3).*spiker - spik3./tau3r);
                    syn1 = syn1 + hz.*(((tau1f+tau1r)./tau1f).*((1-syn1).*spik1.*(2./tau1r) -syn1./tau1f));
                    syn2 = syn2 + hz.*(((tau2f+tau2r)./tau2f).*((1-syn2).*spik2.*(2./tau2r) -syn2./tau2f));
                    syn3 = syn3 + hz.*(((tau3f+tau3r)./tau3f).*((1-syn3).*spik3.*(2./tau3r) -syn3./tau3f));
                    
                    syn1s(1:N,st) = syn1(1:N);
                    syn2s(1:N,st) = syn2(1:N);
                    syn3s(1:N,st) = syn3(1:N);
                    vs(:,st) = v;
                    Ies(:,st) = Ie;
                    Iis(:,st) = Ii;
                    extInp(thaS,st) = max(inp(thaS),0);
                    
                    st = st + 1-sign(mod(t,downsamp)); % index for downsampling
                end % t
                toc
                
                % plotting-related steps
                
                randInp = extInp;
                xPlot = syn1s;
                
                xxx = timevec(1:downsamp:tlen);
                yyy1 = 1:Na;
                yyy2 = 1:NaC;
                yyy3 = 1:NaPV;
                
                y =sum(vs(ctxS(:),:));
                
                figname = mfilename;
                
                resultstring = figname;
                scrsz = get(0,'ScreenSize');
                set(0,'DefaultAxesFontName', 'Arial')
                set(0,'DefaultAxesFontSize', 8)
                                               
                switch manip
                    case 1
                        mstr = ['PV_',num2str(parvar)];
                    case 2
                        mstr = ['CB_',num2str(parvar)];
                    case 3
                        mstr = ['TRN_',num2str(parvar)];
                    case 4
                        mstr = ['STP_',num2str(parvar)];
                    case 5
                        mstr = ['PVx_',num2str(parvar)];
                    case 6
                        mstr = ['CBx_',num2str(parvar)];
                        
                    otherwise
                        mstr = ['Combo',num2str(parvar)];
                end
                
                if saveAllFigs
                    Plot_Trial
                end
                
                datasetname = [dirstring,'/',mstr,'_trial',num2str(trial),'_task',num2str(tsk)];
                
                save(datasetname,'dirstring','figname','visib', 'saveData','mstring','svgflag','imgtype',...
                    'durat','tlen','tlend','downsamp','tfra',...
                    'tposs','cposs','syn1s','randInp','vs','y','errors',...
                    'thaS','ctxS','ctxD','cCBS','cPVS','trnS',...
                    'xxx','yyy1','yyy2','yyy3','mstr','seed','tsk')
                
            end %parvar
        end %tsk
        
    end %manip
    
    
    
end %trial

disp(['Simulation complete. All data saved in folder: ',dirstring])